@@ -1,7 +1,7 @@
 from cloudspotlicense.constants.errors import NoValidToken
 from .base import APIEndpoint
 
-from cloudspotlicense.models.auth import AuthResponse, User, CompanyPermissionsResponse
+from cloudspotlicense.models.auth import AuthResponse, User, CompanyPermissionsResponse, ImpersonateResponse
 
 class AuthMethods(APIEndpoint):
 
@@ -19,6 +19,17 @@ class AuthMethods(APIEndpoint):
         
         return auth_resp
     
+    def validate_impersonation(self, token):
+        endpoint = '{0}/{1}'.format(self.endpoint, 'impersonation-validation')
+        data = { 'token' : token }
+        
+        status, headers, resp_json = self.api.post(endpoint, data)
+        
+        if status != 200: return ImpersonateResponse().parse_error(resp_json)
+        impersonate_resp = ImpersonateResponse().parse(resp_json)
+        
+        return impersonate_resp
+    
     def get_user(self):
         if not self.api.token: raise NoValidToken('No token found. Authenticate the user first to retrieve a token or supply a token to the function.')
         
