@@ -1,5 +1,20 @@
 from .base import BaseModel, ObjectListModel
 
+class ImpersonateResponse(BaseModel):
+    
+    def __init__(self,
+        token=None,
+        auth_token=None,
+        user=None,
+        company=None
+    ):
+        super().__init__()
+        
+        self.token = token
+        self.auth_token = auth_token
+        self.user = user
+        self.company = company
+
 class AuthPermission(BaseModel):
     
     def __init__(self,
